<?php
/**
* The template for adding additional theme options in Customizer
*
* @package Catch Themes
* @subpackage Clean Journal Pro
* @since Clean Journal 1.0
*/

// Additional Color Scheme (added to Color Scheme section in Theme Customizer)
if ( ! defined( 'CLEAN_JOURNAL_THEME_VERSION' ) ) {
header( 'Status: 403 Forbidden' );
header( 'HTTP/1.1 403 Forbidden' );
exit();
}

//Theme Options
$wp_customize->add_panel( 'clean_journal_theme_options', array(
    'description'    => __( 'Basic theme Options', 'clean-journal-pro' ),
    'capability'     => 'edit_theme_options',
    'priority'       => 200,
    'title'    		 => __( 'Theme Options', 'clean-journal-pro' ),
) );

// Breadcrumb Option
$wp_customize->add_section( 'clean_journal_breadcumb_options', array(
	'description'	=> __( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'clean-journal-pro' ),
	'panel'			=> 'clean_journal_theme_options',
	'title'    		=> __( 'Breadcrumb Options', 'clean-journal-pro' ),
	'priority' 		=> 201,
) );

$wp_customize->add_setting( 'clean_journal_theme_options[breadcumb_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_option'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox'
) );

$wp_customize->add_control( 'clean_journal_theme_options[breadcumb_option]', array(
	'label'    => __( 'Check to enable Breadcrumb', 'clean-journal-pro' ),
	'section'  => 'clean_journal_breadcumb_options',
	'settings' => 'clean_journal_theme_options[breadcumb_option]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[breadcumb_onhomepage]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_onhomepage'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox'
) );

$wp_customize->add_control( 'clean_journal_theme_options[breadcumb_onhomepage]', array(
	'label'    => __( 'Check to enable Breadcrumb on Homepage', 'clean-journal-pro' ),
	'section'  => 'clean_journal_breadcumb_options',
	'settings' => 'clean_journal_theme_options[breadcumb_onhomepage]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[breadcumb_seperator]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_seperator'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'clean_journal_theme_options[breadcumb_seperator]', array(
	'input_attrs' => array(
    		'style' => 'width: 40px;'
		),
	'label'    	=> __( 'Separator between Breadcrumbs', 'clean-journal-pro' ),
	'section' 	=> 'clean_journal_breadcumb_options',
	'settings' 	=> 'clean_journal_theme_options[breadcumb_seperator]',
	'type'     	=> 'text'
	)
);
	// Breadcrumb Option End

	// Comment Option
$wp_customize->add_section( 'clean_journal_comment_option', array(
	'description'	=> __( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'clean-journal-pro' ),
	'panel' 		=> 'clean_journal_theme_options',
	'priority'		=> 202,
	'title'   		=> __( 'Comment Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[comment_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['comment_option'],
	'sanitize_callback' => 'clean_journal_sanitize_select',
) );

$wp_customize->add_control( 'clean_journal_theme_options[comment_option]', array(
		'choices'  	=> clean_journal_comment_options(),
		'label'		=> __( 'Comment Option', 'clean-journal-pro' ),
        'priority'	=> 1,
		'section'   => 'clean_journal_comment_option',
        'settings'  => 'clean_journal_theme_options[comment_option]',
        'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[disable_notes]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_notes'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[disable_notes]', array(
	'label'		=> __( 'Check to Disable Notes', 'clean-journal-pro' ),
	'section'   => 'clean_journal_comment_option',
    'settings'  => 'clean_journal_theme_options[disable_notes]',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[disable_website_field]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_website_field'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[disable_website_field]', array(
	'label'		=> __( 'Check to Disable Website Field', 'clean-journal-pro' ),
	'section'   => 'clean_journal_comment_option',
    'settings'  => 'clean_journal_theme_options[disable_website_field]',
	'type'		=> 'checkbox',
) );
	// Comment End

/**
 * Do not show Custom CSS option from WordPress 4.7 onwards
 * @remove when WP 5.0 is released
 */
if ( !function_exists( 'wp_update_custom_css_post' ) ) {
	// Custom CSS Option
	$wp_customize->add_section( 'clean_journal_custom_css', array(
		'description'	=> __( 'Custom/Inline CSS', 'clean-journal-pro'),
		'panel'  		=> 'clean_journal_theme_options',
		'priority' 		=> 203,
		'title'    		=> __( 'Custom CSS Options', 'clean-journal-pro' ),
	) );

	$wp_customize->add_setting( 'clean_journal_theme_options[custom_css]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['custom_css'],
		'sanitize_callback' => 'clean_journal_sanitize_custom_css',
	) );

	$wp_customize->add_control( 'clean_journal_theme_options[custom_css]', array(
			'label'		=> __( 'Enter Custom CSS', 'clean-journal-pro' ),
	        'priority'	=> 1,
			'section'   => 'clean_journal_custom_css',
	        'settings'  => 'clean_journal_theme_options[custom_css]',
			'type'		=> 'textarea',
	) );
	// Custom CSS End
}

	// Excerpt Options
$wp_customize->add_section( 'clean_journal_excerpt_options', array(
	'panel'  	=> 'clean_journal_theme_options',
	'priority' 	=> 204,
	'title'    	=> __( 'Excerpt Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[excerpt_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_length'],
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'clean_journal_theme_options[excerpt_length]', array(
	'description' => __('Excerpt length. Default is 55 words', 'clean-journal-pro'),
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
    'label'    => __( 'Excerpt Length (words)', 'clean-journal-pro' ),
	'section'  => 'clean_journal_excerpt_options',
	'settings' => 'clean_journal_theme_options[excerpt_length]',
	'type'	   => 'number',
	)
);

$wp_customize->add_setting( 'clean_journal_theme_options[excerpt_more_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_more_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'clean_journal_theme_options[excerpt_more_text]', array(
	'label'    => __( 'Read More Text', 'clean-journal-pro' ),
	'section'  => 'clean_journal_excerpt_options',
	'settings' => 'clean_journal_theme_options[excerpt_more_text]',
	'type'	   => 'text',
) );
// Excerpt Options End

// Feed Redirect
$wp_customize->add_section( 'clean_journal_feed_redirect', array(
	'panel'			=> 'clean_journal_theme_options',
	'description'	=> __( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'clean-journal-pro' ),
	'priority' 		=> 205,
	'title'    		=> __( 'Feed Redirect', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[feed_redirect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['feed_redirect'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'clean_journal_theme_options[feed_redirect]', array(
	'label'    => __( 'Feed Redirect', 'clean-journal-pro' ),
	'section'  => 'clean_journal_feed_redirect',
	'settings' => 'clean_journal_theme_options[feed_redirect]',
	'type'	   => 'text',
) );
// Feed Redirect End

// Font Family Options
$wp_customize->add_section( 'clean_journal_font_family', array(
	'panel'  => 'clean_journal_theme_options',
	'priority'	=> 206,
	'title'    	=> __( 'Font Family Options', 'clean-journal-pro' ),
) );

$avaliable_fonts = clean_journal_avaliable_fonts();

$choices = array();

foreach ( $avaliable_fonts as $avaliable_font ) {
	$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
}

$font_family_options	=	array(
									'title_font' 		=> __( 'Site Title Font Family', 'clean-journal-pro' ),
									'body_font' 		=> __( 'Default Font Family', 'clean-journal-pro' ),
									'tagline_font' 		=> __( 'Site Tagline Font Family', 'clean-journal-pro' ),
									'content_title_font'=> __( 'Content Title Font Family', 'clean-journal-pro' ),
									'content_font' 		=> __( 'Content Body Font Family', 'clean-journal-pro' ),
									'headings_font' 	=> __( 'Headings Tags from h1 to h6 Font Family', 'clean-journal-pro' )
								);

foreach ( $font_family_options as $key => $font_family_option ) {
	$wp_customize->add_setting( 'clean_journal_theme_options['. $key . ']', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults[ $key ],
		'sanitize_callback' => 'clean_journal_sanitize_select',
	) );

	$wp_customize->add_control( 'clean_journal_theme_options['. $key . ']', array(
		'choices'  => $choices,
		'label'    => $font_family_option,
		'section'  => 'clean_journal_font_family',
		'settings' => 'clean_journal_theme_options['. $key . ']',
		'type'	   => 'select',
	) );
}

$wp_customize->add_setting( 'clean_journal_theme_options[reset_typography]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_typography'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'clean_journal_theme_options[reset_typography]', array(
	'label'		=> __( 'Check to reset fonts', 'clean-journal-pro' ),
	'section'	=> 'clean_journal_font_family',
	'settings'	=> 'clean_journal_theme_options[reset_typography]',
	'type'		=> 'checkbox',
) );
// Font Family Options End

// Footer Editor Options
$wp_customize->add_section( 'clean_journal_footer_options', array(
	'description'	=> __( 'You can either add html or plain text', 'clean-journal-pro'),
	'panel'  => 'clean_journal_theme_options',
	'priority' 		=> 207,
	'title'    		=> __( 'Footer Editor Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[footer_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_content'],
	'sanitize_callback'	=> 'clean_journal_sanitize_footer_code',
) );

$wp_customize->add_control( 'clean_journal_theme_options[footer_content]', array(
		'description' 	=> __( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'clean-journal-pro' ),
		'label'		=> __( 'Footer Left Content', 'clean-journal-pro' ),
        'priority'	=> 1,
		'section'   => 'clean_journal_footer_options',
        'settings'  => 'clean_journal_theme_options[footer_content]',
		'type'		=> 'textarea',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[reset_footer_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_footer_content'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'clean_journal_theme_options[reset_footer_content]', array(
	'label'		=> __( 'Check to reset Footer Content', 'clean-journal-pro' ),
	'priority'	=> 3,
	'settings'	=> 'clean_journal_theme_options[reset_footer_content]',
	'section'	=> 'clean_journal_footer_options',
	'type'		=> 'checkbox',
) );
// Footer Options End

// Header Right Sidebar Option
$wp_customize->add_section( 'clean_journal_header_right', array(
	'panel'    => 'clean_journal_theme_options',
	'priority' => 208,
	'title'    => __( 'Header Right Sidebar Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[disable_header_right_sidebar]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_header_right_sidebar'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox'
) );

$wp_customize->add_control( 'clean_journal_theme_options[disable_header_right_sidebar]', array(
	'label'    	=> __( 'Check to disable Header Right Sidebar', 'clean-journal-pro' ),
	'section'  	=> 'clean_journal_header_right',
	'settings' 	=> 'clean_journal_theme_options[disable_header_right_sidebar]',
	'type'     	=> 'checkbox',
) );
// Header Right Sidebar Option End

// Header Top
$wp_customize->add_section( 'clean_journal_header_top', array(
	'panel'			=> 'clean_journal_theme_options',
	'description'	=> __( 'Header Top Options', 'clean-journal-pro' ),
	'priority' 		=> 208.5,
	'title'    		=> __( 'Header Top Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[disable_header_top]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_header_top'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[disable_header_top]', array(
	'label'    => __( 'Check to disable header top', 'clean-journal-pro' ),
	'section'  => 'clean_journal_header_top',
	'settings' => 'clean_journal_theme_options[disable_header_top]',
	'type'	   => 'checkbox',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[fixed_header_top]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['fixed_header_top'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[fixed_header_top]', array(
	'active_callback'	=> 'clean_journal_is_header_top_enabled',
	'label'    			=> __( 'Check to fix header to top', 'clean-journal-pro' ),
	'section'  			=> 'clean_journal_header_top',
	'settings' 			=> 'clean_journal_theme_options[fixed_header_top]',
	'type'	   			=> 'checkbox',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[header_top_left_sidebar_width]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['header_top_left_sidebar_width'],
	'sanitize_callback'	=> 'clean_journal_sanitize_number_range'
) );

$wp_customize->add_control( 'clean_journal_theme_options[header_top_left_sidebar_width]', array(
	'active_callback'	=> 'clean_journal_is_header_top_enabled',
    'type'        		=> 'number',
    'section'     		=> 'clean_journal_header_top',
    'label'    			=> __( 'Header Top Left Sidebar Widget Area Width ', 'clean-journal-pro' ),
    'description'		=> __( 'This is Width for Header Top Left Sidebar Widget Area. Once this is adjusted, the width for Header Top Right Sidebar Widget Area is set automatically. in %', 'clean-journal-pro' ),
    'input_attrs' 		=> array(
        'min'   => 10,
        'max'   => 100,
        'style' => 'width: 50px;'
        ),
	)
);
// Header Top End

//Homepage / Frontpage Options
$wp_customize->add_section( 'clean_journal_homepage_options', array(
	'description'	=> __( 'Only posts that belong to the categories selected here will be displayed on the front page', 'clean-journal-pro' ),
	'panel'			=> 'clean_journal_theme_options',
	'priority' 		=> 209,
	'title'   	 	=> __( 'Homepage / Frontpage Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[front_page_category]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'clean_journal_sanitize_category_list',
) );

$wp_customize->add_control( new Clean_Journal_Customize_Dropdown_Categories_Control( $wp_customize, 'clean_journal_theme_options[front_page_category]', array(
    'label'   	=> __( 'Select Categories', 'clean-journal-pro' ),
    'name'	 	=> 'clean_journal_theme_options[front_page_category]',
	'priority'	=> '6',
    'section'  	=> 'clean_journal_homepage_options',
    'settings' 	=> 'clean_journal_theme_options[front_page_category]',
    'type'     	=> 'dropdown-categories',
) ) );
//Homepage / Frontpage Settings End


// Layout Options
$wp_customize->add_section( 'clean_journal_layout', array(
	'capability'=> 'edit_theme_options',
	'panel'		=> 'clean_journal_theme_options',
	'priority'	=> 211,
	'title'		=> __( 'Layout Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[theme_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['theme_layout'],
	'sanitize_callback' => 'clean_journal_sanitize_select',
) );

$wp_customize->add_control( 'clean_journal_theme_options[theme_layout]', array(
	'choices'	=> clean_journal_layouts(),
	'label'		=> __( 'Default Layout', 'clean-journal-pro' ),
	'section'	=> 'clean_journal_layout',
	'settings'   => 'clean_journal_theme_options[theme_layout]',
	'type'		=> 'select',
) );

if ( class_exists( 'WooCommerce' ) ) {
	$wp_customize->add_setting( 'clean_journal_theme_options[woocommerce_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['woocommerce_layout'],
		'sanitize_callback' => 'clean_journal_sanitize_select',
	) );

	$wp_customize->add_control( 'clean_journal_theme_options[woocommerce_layout]', array(
		'choices'	=> clean_journal_layouts(),
		'label'		=> __( 'Woocommerce Layout', 'clean-journal-pro' ),
		'section'	=> 'clean_journal_layout',
		'settings'   => 'clean_journal_theme_options[woocommerce_layout]',
		'type'		=> 'select',
	) );
}

$wp_customize->add_setting( 'clean_journal_theme_options[content_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['content_layout'],
	'sanitize_callback' => 'clean_journal_sanitize_select',
) );

$wp_customize->add_control( 'clean_journal_theme_options[content_layout]', array(
	'choices'   => clean_journal_get_archive_content_layout(),
	'label'		=> __( 'Archive Content Layout', 'clean-journal-pro' ),
	'section'   => 'clean_journal_layout',
	'settings'  => 'clean_journal_theme_options[content_layout]',
	'type'      => 'select',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[single_post_image_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['single_post_image_layout'],
	'sanitize_callback' => 'clean_journal_sanitize_select',
) );

$wp_customize->add_control( 'clean_journal_theme_options[single_post_image_layout]', array(
		'label'		=> __( 'Single Page/Post Image Layout ', 'clean-journal-pro' ),
		'section'   => 'clean_journal_layout',
        'settings'  => 'clean_journal_theme_options[single_post_image_layout]',
        'type'	  	=> 'select',
		'choices'  	=> clean_journal_single_post_image_layout_options(),
) );
	// Layout Options End

// Pagination Options
$pagination_type	= $options['pagination_type'];

$clean_journal_navigation_description = sprintf( __( 'Numeric Option requires <a target="_blank" href="%1$s">WP-PageNavi Plugin</a>.<br/>Infinite Scroll Options requires <a target="_blank" href="%2$s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'clean-journal-pro' ), esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ), esc_url( 'https://wordpress.org/plugins/jetpack/' ) );

/**
 * Check if navigation type is Jetpack Infinite Scroll and if it is enabled
 */
if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
	if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
		$clean_journal_navigation_description = sprintf( __( 'Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'clean-journal-pro' ), esc_url( 'https://wordpress.org/plugins/jetpack/' ) );
	}
	else {
		$clean_journal_navigation_description = '';
	}
}
/**
* Check if navigation type is numeric and if Wp-PageNavi Plugin is enabled
*/
else if ( 'numeric' == $pagination_type ) {
	if ( !function_exists( 'wp_pagenavi' ) ) {
		$clean_journal_navigation_description = sprintf( __( 'Numeric Option requires <a target="_blank" href="%s">WP-PageNavi Plugin</a>.', 'clean-journal-pro' ), esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ) );
	}
	else {
		$clean_journal_navigation_description = '';
	}
}

$wp_customize->add_section( 'clean_journal_pagination_options', array(
	'description'	=> $clean_journal_navigation_description,
	'panel'  		=> 'clean_journal_theme_options',
	'priority'		=> 212,
	'title'    		=> __( 'Pagination Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[pagination_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['pagination_type'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'clean_journal_theme_options[pagination_type]', array(
	'choices'  => clean_journal_get_pagination_types(),
	'label'    => __( 'Pagination type', 'clean-journal-pro' ),
	'section'  => 'clean_journal_pagination_options',
	'settings' => 'clean_journal_theme_options[pagination_type]',
	'type'	   => 'select',
) );
// Pagination Options End

//Promotion Headline Options
$wp_customize->add_section( 'clean_journal_promotion_headline_options', array(
	'description'	=> __( 'To disable the fields, simply leave them empty.', 'clean-journal-pro' ),
	'panel'			=> 'clean_journal_theme_options',
	'priority' 		=> 213,
	'title'   	 	=> __( 'Promotion Headline Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[promotion_headline_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['promotion_headline_option'],
	'sanitize_callback' => 'clean_journal_sanitize_select',
) );

$wp_customize->add_control( 'clean_journal_theme_options[promotion_headline_option]', array(
	'choices'  	=> clean_journal_featured_slider_content_options(),
	'label'    	=> __( 'Enable Promotion Headline on', 'clean-journal-pro' ),
	'priority'	=> '0.5',
	'section'  	=> 'clean_journal_promotion_headline_options',
	'settings' 	=> 'clean_journal_theme_options[promotion_headline_option]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[promotion_headline]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'clean_journal_theme_options[promotion_headline]', array(
	'description'	=> __( 'Appropriate Words: 10', 'clean-journal-pro' ),
	'label'    	=> __( 'Promotion Headline Text', 'clean-journal-pro' ),
	'priority'	=> '1',
	'section' 	=> 'clean_journal_promotion_headline_options',
	'settings'	=> 'clean_journal_theme_options[promotion_headline]',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[promotion_subheadline]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_subheadline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'clean_journal_theme_options[promotion_subheadline]', array(
	'description'	=> __( 'Appropriate Words: 15', 'clean-journal-pro' ),
	'label'    	=> __( 'Promotion Subheadline Text', 'clean-journal-pro' ),
	'priority'	=> '2',
	'section' 	=> 'clean_journal_promotion_headline_options',
	'settings'	=> 'clean_journal_theme_options[promotion_subheadline]',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[promotion_headline_button]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_button'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'clean_journal_theme_options[promotion_headline_button]', array(
	'description'	=> __( 'Appropriate Words: 3', 'clean-journal-pro' ),
	'label'    	=> __( 'Promotion Headline Button Text ', 'clean-journal-pro' ),
	'priority'	=> '3',
	'section' 	=> 'clean_journal_promotion_headline_options',
	'settings'	=> 'clean_journal_theme_options[promotion_headline_button]',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[promotion_headline_url]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_url'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'clean_journal_theme_options[promotion_headline_url]', array(
	'label'    	=> __( 'Promotion Headline Link', 'clean-journal-pro' ),
	'priority'	=> '4',
	'section' 	=> 'clean_journal_promotion_headline_options',
	'settings'	=> 'clean_journal_theme_options[promotion_headline_url]',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[promotion_headline_target]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_target'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[promotion_headline_target]', array(
	'label'    	=> __( 'Check to Open Link in New Window/Tab', 'clean-journal-pro' ),
	'priority'	=> '5',
	'section'  	=> 'clean_journal_promotion_headline_options',
	'settings' 	=> 'clean_journal_theme_options[promotion_headline_target]',
	'type'     	=> 'checkbox',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[promotion_headline_left_width]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_left_width'],
	'sanitize_callback'	=> 'clean_journal_sanitize_number_range'
) );

$wp_customize->add_control( 'clean_journal_theme_options[promotion_headline_left_width]', array(
'type'        	=> 'number',
'priority'   	=> '6',
'section'     	=> 'clean_journal_promotion_headline_options',
'label'    		=> __( 'Promotion Headline Left Section Width', 'clean-journal-pro' ),
'description'	=> __( 'This is promotion headline left section width. Once this is adjusted, the width for promotion headline right section is set automatically. in %', 'clean-journal-pro' ),
'input_attrs' => array(
    'min'   => 10,
    'max'   => 100,
    'style' => 'width: 50px;'
    ),
) );
// Promotion Headline Options End

// Responsive Options
$wp_customize->add_section( 'clean_journal_responsive_options', array(
	'panel'  => 'clean_journal_theme_options',
	'priority' => 214,
	'title'    => __( 'Responsive Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[footer_mobile_menu_disable]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_mobile_menu_disable'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[footer_mobile_menu_disable]', array(
	'label'    => __( 'Check to disable footer mobile menu', 'clean-journal-pro' ),
	'section'  => 'clean_journal_responsive_options',
	'settings' => 'clean_journal_theme_options[footer_mobile_menu_disable]',
	'type'     => 'checkbox',
) );
	// Responsive Options End

// Scrollup
$wp_customize->add_section( 'clean_journal_scrollup', array(
	'panel'    => 'clean_journal_theme_options',
	'priority' => 215,
	'title'    => __( 'Scrollup Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[disable_scrollup]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_scrollup'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[disable_scrollup]', array(
	'label'		=> __( 'Check to disable Scroll Up', 'clean-journal-pro' ),
	'section'   => 'clean_journal_scrollup',
    'settings'  => 'clean_journal_theme_options[disable_scrollup]',
	'type'		=> 'checkbox',
) );
// Scrollup End

// Search Options
$wp_customize->add_section( 'clean_journal_search_options', array(
	'description'=> __( 'Change default placeholder text in Search.', 'clean-journal-pro'),
	'panel'  => 'clean_journal_theme_options',
	'priority' => 216,
	'title'    => __( 'Search Options', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[search_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['search_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'clean_journal_theme_options[search_text]', array(
	'label'		=> __( 'Default Display Text in Search', 'clean-journal-pro' ),
	'section'   => 'clean_journal_search_options',
    'settings'  => 'clean_journal_theme_options[search_text]',
	'type'		=> 'text',
) );
// Search Options End

// Single Post Navigation
$wp_customize->add_section( 'clean_journal_single_post_navigation', array(
	'panel'  => 'clean_journal_theme_options',
	'priority' => 217,
	'title'    => __( 'Single Post Navigation', 'clean-journal-pro' ),
) );

$wp_customize->add_setting( 'clean_journal_theme_options[disable_single_post_navigation]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_single_post_navigation'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[disable_single_post_navigation]', array(
	'label'		=> __( 'Check to disable Single Post Navigation', 'clean-journal-pro' ),
	'section'   => 'clean_journal_single_post_navigation',
    'settings'  => 'clean_journal_theme_options[disable_single_post_navigation]',
	'type'		=> 'checkbox',
) );
// Single Post Navigation End

// Update Notifier
$wp_customize->add_section( 'clean_journal_update_notifier', array(
	'title'    => __( 'Update Notifier', 'clean-journal-pro' ),
	'priority' => 217,
	'panel'    => 'clean_journal_theme_options',
) );

$wp_customize->add_setting( 'clean_journal_theme_options[update_notifier]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['update_notifier'],
	'sanitize_callback' => 'clean_journal_sanitize_checkbox',
) );

$wp_customize->add_control( 'clean_journal_theme_options[update_notifier]', array(
	'label'		=> __( 'Check to disable update notifications', 'clean-journal-pro' ),
	'section'   => 'clean_journal_update_notifier',
    'settings'  => 'clean_journal_theme_options[update_notifier]',
	'type'		=> 'checkbox',
) );
// Update Notifier End
//Theme Option End